function fF = filtre_Fourier(sizeI, F, S)
% utilisation: fF = filtre_Fourier(sizeI,F,S);
% transformee de Fourier du filtre F
% sizeI : taille de l image (paire)
% F : filtre a 'fourieriser' (taille impaire)
% S : seuil en dessous duquel les coefs de module < S sont mis à S
% (S=0: pas de modification)
h=zeros(sizeI,sizeI);
newcoords= sizeI/2+1-(length(F)-1)/2 : sizeI/2+1+(length(F)-1)/2;
h(newcoords,newcoords) = F;
h=fft2(ifftshift(h));
ind=find(abs(h)<S);
h(ind)=S*exp(i*angle(h(ind)));
fF=h;
